@@ -2,11 +2,13 @@
 from .component_utils import (
     create_component_id,
     set_component_id,
-    create_binary_mixture_id
+    create_binary_mixture_id,
+    create_mixture_id
 )
 
 __all__ = [
     "create_component_id",
     "set_component_id",
     "create_binary_mixture_id",
+    "create_mixture_id"
 ]
